@@ -7,13 +7,14 @@ class ProactorService(asab.Service):
 	def __init__(self, app, service_name):
 		super().__init__(app, service_name)
 		self.Loop = app.Loop
-		
+
 		max_workers = asab.Config.get('asab:proactor', 'max_workers')
 		try:
 			max_workers = int(max_workers)
-		except:
+		except BaseException:
+			max_workers = None
+		if max_workers <= 0:
 			max_workers = None
-		if max_workers <= 0: max_workers = None
 
 		self.Executor = concurrent.futures.ThreadPoolExecutor(
 			max_workers=max_workers,
