@@ -7,14 +7,6 @@ L = logging.getLogger(__name__)
 
 #
 
-asab.Config.add_defaults(
-	{
-		'asab:storage': {
-			'type': 'inmemory',
-		}
-	}
-)
-
 
 class Module(asab.Module):
 
@@ -30,5 +22,9 @@ class Module(asab.Module):
 			from .mongodb import StorageService
 			self.Service = StorageService(app, "asab.StorageService")
 
+		elif sttype == "elasticsearch":
+			from .elasticsearch import StorageService
+			self.Service = StorageService(app, "asab.StorageService")
+
 		else:
 			L.error("Unknown asab:storage type '{}'".format(sttype))
